# OctoPrint OneDrive Communication Module

This is used in my two plugins - [OctoPrint OneDrive Backup](https://github.com/cp2004/OctoPrint-OneDrive-Backup) and [OctoPrint OneDrive File Sync](https://github.com/cp2004/OctoPrint-OneDriveFileSync).

It is made for my own purposes to unify the code across the two plugins, making maintenance a bit easier. As such it has no documentation or stable API guarantees and I don't recommend you try and use it for your project.

It is hosted on PyPi and can be installed with pip:

```
pip install octo-onedrive
```
